@@ -1,8 +1,8 @@
-use std::collections::HashSet;
+use std::collections::{HashMap, HashSet};
 use std::fmt;
 use std::fmt::Display;
 use std::fmt::Formatter;
-
+use std::hash::{DefaultHasher, Hash, Hasher};
 use crate::field::Field;
 use crate::function::Function;
 use crate::operators::ArithmeticOp;
@@ -24,6 +24,7 @@ pub struct Expr {
     pub val: Option<String>,
     pub subquery: Option<Box<Query>>,
     pub root_alias: Option<String>,
+    pub alias: Option<String>,
     pub weight: i32,
 }
 
@@ -42,6 +43,7 @@ impl Expr {
             val: None,
             subquery: None,
             root_alias: None,
+            alias: None,
             weight: 0,
         }
     }
@@ -63,6 +65,7 @@ impl Expr {
             val: None,
             subquery: None,
             root_alias: None,
+            alias: None,
             weight: left_weight + right_weight,
         }
     }
@@ -84,6 +87,7 @@ impl Expr {
             val: None,
             subquery: None,
             root_alias: None,
+            alias: None,
             weight: left_weight + right_weight,
         }
     }
@@ -105,6 +109,7 @@ impl Expr {
             val: None,
             subquery: None,
             root_alias: None,
+            alias: None,
             weight: left_weight + right_weight,
         }
     }
@@ -125,6 +130,7 @@ impl Expr {
             val: None,
             subquery: None,
             root_alias: None,
+            alias: None,
             weight,
         }
     }
@@ -145,6 +151,7 @@ impl Expr {
             val: None,
             subquery: None,
             root_alias,
+            alias: None,
             weight,
         }
     }
@@ -165,6 +172,7 @@ impl Expr {
             val: None,
             subquery: None,
             root_alias: None,
+            alias: None,
             weight,
         }
     }
@@ -189,6 +197,7 @@ impl Expr {
             val: None,
             subquery: None,
             root_alias: None,
+            alias: None,
             weight: weight + left_weight,
         }
     }
@@ -207,6 +216,7 @@ impl Expr {
             val: Some(value),
             subquery: None,
             root_alias: None,
+            alias: None,
             weight: 0,
         }
     }
@@ -230,6 +240,7 @@ impl Expr {
             val: None,
             subquery: Some(Box::new(subquery)),
             root_alias: None,
+            alias: None,
             weight,
         }
     }
@@ -303,8 +314,8 @@ impl Expr {
         result
     }
     
-    pub fn get_fields_required_in_subqueries(&self, alias: &str, parent_subquery: bool) -> HashSet<Field> {
-        let mut result = HashSet::new();
+    pub fn get_fields_required_in_subqueries(&self, alias: &str, parent_subquery: bool) -> HashMap<Field, String> {
+        let mut result = HashMap::new();
 
         if let Some(ref subquery) = self.subquery {
             if let Some(ref expr) = subquery.expr {
@@ -324,7 +335,8 @@ impl Expr {
             if expr_alias == alias {
                 if let Some(field) = self.field {
                     if parent_subquery {
-                        result.insert(field);
+                        let alias = if let Some(ref alias) = self.alias { alias } else { &field.to_string() };
+                        result.insert(field, alias.clone());
                     }
                 }
             }
@@ -411,17 +423,37 @@ impl Display for Expr {
     fn fmt(&self, fmt: &mut Formatter) -> fmt::Result {
         use std::fmt::Write;
 
+        if let Some(ref subquery) = self.subquery {
+            if let Some(ref alias) = self.alias {
+                if let Some(ref root_alias) = self.root_alias {
+                    fmt.write_str(&root_alias.to_string())?;
+                    fmt.write_char('.')?;
+                }
+                fmt.write_str(&alias.to_string())?;
+            } else {
+                let subquery_str = format!("{:?}", subquery);
+                let mut s = DefaultHasher::new();
+                subquery_str.hash(&mut s);
+                let hash = s.finish();
+                fmt.write_str(("subquery_".to_string() + hash.to_string().as_str()).as_str())?;
+            }
+        }
+
         if self.minus {
             fmt.write_char('-')?;
         }
 
         if let Some(ref function) = self.function {
-            fmt.write_str(&function.to_string())?;
-            fmt.write_char('(')?;
-            if let Some(ref left) = self.left {
-                fmt.write_str(&left.to_string())?;
+            if let Some(ref alias) = self.alias {
+                fmt.write_str(&alias.to_string())?;
+            } else {
+                fmt.write_str(&function.to_string())?;
+                fmt.write_char('(')?;
+                if let Some(ref left) = self.left {
+                    fmt.write_str(&left.to_string())?;
+                }
+                fmt.write_char(')')?;
             }
-            fmt.write_char(')')?;
         } else if let Some(ref left) = self.left {
             fmt.write_str(&left.to_string())?;
         }
@@ -431,7 +463,11 @@ impl Display for Expr {
                 fmt.write_str(&root_alias.to_string())?;
                 fmt.write_char('.')?;
             }
-            fmt.write_str(&field.to_string())?;
+            if let Some(ref alias) = self.alias {
+                fmt.write_str(&alias.to_string())?;
+            } else {
+                fmt.write_str(&field.to_string())?;
+            }
         }
 
         if let Some(ref val) = self.val {
@@ -525,12 +561,6 @@ mod tests {
         query.expr.expect("query should have where expr")
     }
 
-    fn set_of(fields: Vec<Field>) -> HashSet<Field> {
-        let mut s = HashSet::new();
-        for f in fields { s.insert(f); }
-        s
-    }
-
     #[test]
     fn no_subqueries_returns_fields_from_top_level_for_alias() {
         let expr = parse_where_expr("select t1.name from /t1 as t1 where t1.size > 10");
@@ -552,8 +582,8 @@ mod tests {
         let expr = parse_where_expr(
             "select t1.name from /t1 as t1 where exists(select t2.name from /t2 as t2 where t2.name = t1.name and t2.size > t1.size)"
         );
-        let set = expr.get_fields_required_in_subqueries("t1", false);
-        assert_eq!(set, set_of(vec![Field::Name, Field::Size]));
+        let map = expr.get_fields_required_in_subqueries("t1", false);
+        assert_eq!(map, HashMap::from([(Field::Name, String::from("Name")), (Field::Size, String::from("Size"))]));
         let set = expr.right.unwrap().subquery.unwrap().expr.unwrap().get_fields_required_in_subqueries("t2", false);
         assert!(set.is_empty(), "Expected no required fields for t2 in correlated subquery");
     }
@@ -563,10 +593,10 @@ mod tests {
         let expr = parse_where_expr(
             "select t1.name from /t1 as t1 where not exists(select t2.name from /t2 as t2 where t2.name = t1.name and t2.size > t1.size)"
         );
-        let set = expr.get_fields_required_in_subqueries("t1", false);
-        assert_eq!(set, set_of(vec![Field::Name, Field::Size]));
-        let set = expr.right.unwrap().subquery.unwrap().expr.unwrap().get_fields_required_in_subqueries("t2", false);
-        assert!(set.is_empty(), "Expected no required fields for t2 in correlated subquery");
+        let map = expr.get_fields_required_in_subqueries("t1", false);
+        assert_eq!(map, HashMap::from([(Field::Name, String::from("Name")), (Field::Size, String::from("Size"))]));
+        let map = expr.right.unwrap().subquery.unwrap().expr.unwrap().get_fields_required_in_subqueries("t2", false);
+        assert!(map.is_empty(), "Expected no required fields for t2 in correlated subquery");
     }
 
     #[test]
@@ -574,13 +604,13 @@ mod tests {
         let expr = parse_where_expr(
             "select t1.name from /t1 as t1 where exists(select t2.name from /t2 as t2 where t2.name in (select t3.name from /t3 as t3 where t3.modified = t1.modified) and t2.size > t1.size)"
         );
-        let set = expr.get_fields_required_in_subqueries("t1", false);
-        assert_eq!(set, set_of(vec![Field::Modified, Field::Size]));
-        let set = expr.clone().right.unwrap().subquery.unwrap().expr.unwrap().get_fields_required_in_subqueries("t2", false);
-        assert!(set.is_empty(), "Expected no required fields for t2 in correlated subquery");
-        let set = expr.clone().right.unwrap().subquery.unwrap().expr.unwrap().left.unwrap().right.unwrap().subquery.unwrap().expr.unwrap().get_fields_required_in_subqueries("t3", false);
-        assert!(set.is_empty(), "Expected no required fields for t3 in correlated subquery");
-        let set = expr.right.unwrap().subquery.unwrap().expr.unwrap().left.unwrap().right.unwrap().subquery.unwrap().expr.unwrap().get_fields_required_in_subqueries("t1", false);
-        assert!(set.is_empty(), "Expected no required fields for t1 in correlated subquery");
+        let map = expr.get_fields_required_in_subqueries("t1", false);
+        assert_eq!(map, HashMap::from([(Field::Modified, String::from("Modified")), (Field::Size, String::from("Size"))]));
+        let map = expr.clone().right.unwrap().subquery.unwrap().expr.unwrap().get_fields_required_in_subqueries("t2", false);
+        assert!(map.is_empty(), "Expected no required fields for t2 in correlated subquery");
+        let map = expr.clone().right.unwrap().subquery.unwrap().expr.unwrap().left.unwrap().right.unwrap().subquery.unwrap().expr.unwrap().get_fields_required_in_subqueries("t3", false);
+        assert!(map.is_empty(), "Expected no required fields for t3 in correlated subquery");
+        let map = expr.right.unwrap().subquery.unwrap().expr.unwrap().left.unwrap().right.unwrap().subquery.unwrap().expr.unwrap().get_fields_required_in_subqueries("t1", false);
+        assert!(map.is_empty(), "Expected no required fields for t1 in correlated subquery");
     }
 }
\ No newline at end of file
