@@ -282,6 +282,27 @@ functions! {
         @group = "Numeric"
         @description = "Get the largest value"
         Greatest,
+        
+        #[text = ["pi"], data_type = "numeric"]
+        @weight = 1
+        @group = "Numeric"
+        @description = "Get the value of Pi (π)"
+        Pi,
+        
+        #[text = ["floor"], data_type = "numeric"]
+        @group = "Numeric"
+        @description = "Round down to the nearest integer"
+        Floor,
+        
+        #[text = ["ceil", "ceiling"], data_type = "numeric"]
+        @group = "Numeric"
+        @description = "Round up to the nearest integer"
+        Ceil,
+        
+        #[text = ["round"], data_type = "numeric"]
+        @group = "Numeric"
+        @description = "Round to the nearest integer"
+        Round,
     
         #[text = ["contains_japanese", "japanese"], data_type = "boolean"]
         @group = "Japanese string"
@@ -489,7 +510,7 @@ functions! {
 /// If no function is provided, the original value is returned.
 ///
 /// Args:
-///  function: Optional specification of which function to apply.
+///  function: The specification of which function to apply.
 ///  function_arg: The value to apply the function to.
 ///  function_args: Additional arguments to the function.
 ///  entry: Optional directory entry to read the file contents from.
@@ -498,18 +519,17 @@ functions! {
 /// Returns:
 ///   A variant containing the value computed or the original value if no function is provided.
 pub fn get_value(
-    function: &Option<Function>,
+    function: &Function,
     function_arg: String,
     function_args: Vec<String>,
     entry: Option<&DirEntry>,
     file_info: &Option<FileInfo>,
 ) -> Variant {
-    //* Refer to the Function enum for a list of available functions and their descriptions
     match function {
         // ===== String functions =====
-        Some(Function::Lower) => Variant::from_string(&function_arg.to_lowercase()),
-        Some(Function::Upper) => Variant::from_string(&function_arg.to_uppercase()),
-        Some(Function::InitCap) => {
+        Function::Lower => Variant::from_string(&function_arg.to_lowercase()),
+        Function::Upper => Variant::from_string(&function_arg.to_uppercase()),
+        Function::InitCap => {
             let result = function_arg
                 .split_whitespace()
                 .map(|s| capitalize(&s.to_lowercase()))
@@ -517,16 +537,13 @@ pub fn get_value(
                 .join(" ");
             Variant::from_string(&result)
         }
-        // Get the length of the string
-        Some(Function::Length) => {
+        Function::Length => {
             Variant::from_int(function_arg.chars().count() as i64)
         }
-        // Convert the value to base64
-        Some(Function::ToBase64) => {
+        Function::ToBase64 => {
             Variant::from_string(&rbase64::encode((function_arg).as_ref()))
         }
-        // Read the value as base64
-        Some(Function::FromBase64) => {
+        Function::FromBase64 => {
             Variant::from_string(
                 &String::from_utf8_lossy(&rbase64::decode(&function_arg).unwrap_or_default())
                     .to_string(),
@@ -534,11 +551,11 @@ pub fn get_value(
         }
 
         // ===== String manipulation functions =====
-        Some(Function::Concat) => {
+        Function::Concat => {
             Variant::from_string(&(String::from(&function_arg) + &function_args.join("")))
         }
-        Some(Function::ConcatWs) => Variant::from_string(&function_args.join(&function_arg)),
-        Some(Function::Locate) => {
+        Function::ConcatWs => Variant::from_string(&function_args.join(&function_arg)),
+        Function::Locate => {
             let string = String::from(&function_arg);
             let substring = &function_args[0];
             let pos: i32 = match &function_args.get(1) {
@@ -554,7 +571,7 @@ pub fn get_value(
 
             Variant::from_int(result)
         },
-        Some(Function::Substring) => {
+        Function::Substring => {
             let string = String::from(&function_arg);
 
             let mut pos: i32 = match &function_args.is_empty() {
@@ -579,7 +596,7 @@ pub fn get_value(
 
             Variant::from_string(&result)
         }
-        Some(Function::Replace) => {
+        Function::Replace => {
             let source = function_arg;
             let from = &function_args[0];
             let to = &function_args[1];
@@ -588,34 +605,34 @@ pub fn get_value(
 
             Variant::from_string(&result)
         }
-        Some(Function::Trim) => {
+        Function::Trim => {
             Variant::from_string(&function_arg.trim().to_string())
         }
-        Some(Function::LTrim) => {
+        Function::LTrim => {
             Variant::from_string(&function_arg.trim_start().to_string())
         }
-        Some(Function::RTrim) => {
+        Function::RTrim => {
             Variant::from_string(&function_arg.trim_end().to_string())
         }
 
         // ===== Numeric functions =====
-        Some(Function::Bin) => match function_arg.parse::<i64>() {
+        Function::Bin => match function_arg.parse::<i64>() {
             Ok(val) => Variant::from_string(&format!("{:b}", val)),
             _ => Variant::empty(VariantType::String),
         },
-        Some(Function::Hex) => match function_arg.parse::<i64>() {
+        Function::Hex => match function_arg.parse::<i64>() {
             Ok(val) => Variant::from_string(&format!("{:x}", val)),
             _ => Variant::empty(VariantType::String),
         },
-        Some(Function::Oct) => match function_arg.parse::<i64>() {
+        Function::Oct => match function_arg.parse::<i64>() {
             Ok(val) => Variant::from_string(&format!("{:o}", val)),
             _ => Variant::empty(VariantType::String),
         },
-        Some(Function::Abs) => match function_arg.parse::<f64>() {
+        Function::Abs => match function_arg.parse::<f64>() {
             Ok(val) => Variant::from_float(val.abs()),
             _ => Variant::empty(VariantType::String),
         }
-        Some(Function::Power) => {
+        Function::Power => {
             match function_arg.parse::<f64>() {
                 Ok(val) => {
                     let power = match function_args.first() {
@@ -628,11 +645,11 @@ pub fn get_value(
                 _ => Variant::empty(VariantType::String),
             }
         }
-        Some(Function::Sqrt) => match function_arg.parse::<f64>() {
+        Function::Sqrt => match function_arg.parse::<f64>() {
             Ok(val) => Variant::from_float(val.sqrt()),
             _ => Variant::empty(VariantType::String),
         },
-        Some(Function::Log) => {
+        Function::Log => {
             match function_arg.parse::<f64>() {
                 Ok(val) => {
                     let base = match function_args.first() {
@@ -645,15 +662,15 @@ pub fn get_value(
                 _ => Variant::empty(VariantType::String),
             }
         }
-        Some(Function::Ln) => match function_arg.parse::<f64>() {
+        Function::Ln => match function_arg.parse::<f64>() {
             Ok(val) => Variant::from_float(val.ln()),
             _ => Variant::empty(VariantType::String),
         }
-        Some(Function::Exp) => match function_arg.parse::<f64>() {
+        Function::Exp => match function_arg.parse::<f64>() {
             Ok(val) => Variant::from_float(val.exp()),
             _ => Variant::empty(VariantType::String),
         }
-        Some(Function::Least) => {
+        Function::Least => {
             match function_arg.parse::<f64>() {
                 Ok(val) => {
                     let mut least = val;
@@ -668,7 +685,7 @@ pub fn get_value(
                 _ => Variant::empty(VariantType::String),
             }
         }
-        Some(Function::Greatest) => {
+        Function::Greatest => {
             match function_arg.parse::<f64>() {
                 Ok(val) => {
                     let mut greatest = val;
@@ -683,26 +700,41 @@ pub fn get_value(
                 _ => Variant::empty(VariantType::String),
             }
         }
+        Function::Pi => {
+            Variant::from_float(std::f64::consts::PI)
+        }
+        Function::Floor => match function_arg.parse::<f64>() {
+            Ok(val) => Variant::from_float(val.floor()),
+            _ => Variant::empty(VariantType::String),
+        },
+        Function::Ceil => match function_arg.parse::<f64>() {
+            Ok(val) => Variant::from_float(val.ceil()),
+            _ => Variant::empty(VariantType::String),
+        },
+        Function::Round => match function_arg.parse::<f64>() {
+            Ok(val) => Variant::from_float(val.round()),
+            _ => Variant::empty(VariantType::String),
+        },
 
         // ===== Japanese string functions =====
-        Some(Function::ContainsJapanese) => {
+        Function::ContainsJapanese => {
             Variant::from_bool(crate::util::japanese::contains_japanese(&function_arg))
         }
-        Some(Function::ContainsHiragana) => {
+        Function::ContainsHiragana => {
             Variant::from_bool(crate::util::japanese::contains_hiragana(&function_arg))
         }
-        Some(Function::ContainsKatakana) => {
+        Function::ContainsKatakana => {
             Variant::from_bool(crate::util::japanese::contains_katakana(&function_arg))
         }
-        Some(Function::ContainsKana) => {
+        Function::ContainsKana => {
             Variant::from_bool(crate::util::japanese::contains_kana(&function_arg))
         }
-        Some(Function::ContainsKanji) => {
+        Function::ContainsKanji => {
             Variant::from_bool(crate::util::japanese::contains_kanji(&function_arg))
         }
 
         // ===== Formatting functions =====
-        Some(Function::FormatSize) => {
+        Function::FormatSize => {
             if function_arg.is_empty() {
                 return Variant::empty(VariantType::String);
             }
@@ -718,7 +750,7 @@ pub fn get_value(
 
             Variant::empty(VariantType::String)
         }
-        Some(Function::FormatTime) => {
+        Function::FormatTime => {
             if function_arg.is_empty() {
                 return Variant::empty(VariantType::String);
             }
@@ -729,55 +761,55 @@ pub fn get_value(
         }
 
         // ===== Datetime functions =====
-        Some(Function::CurrentDate) => {
+        Function::CurrentDate => {
             let now = Local::now().date_naive();
             Variant::from_string(&format_date(&now))
         }
-        Some(Function::CurrentTime) => {
+        Function::CurrentTime => {
             let now = Local::now().time();
             Variant::from_string(&format_time(&now))
         }
-        Some(Function::CurrentTimestamp) => {
+        Function::CurrentTimestamp => {
             let now = Local::now().naive_local();
             Variant::from_string(&format_datetime(&now))
         }
-        Some(Function::Year) => match parse_datetime(&function_arg) {
+        Function::Year => match parse_datetime(&function_arg) {
             Ok(date) => Variant::from_int(date.0.year() as i64),
             _ => Variant::empty(VariantType::Int),
         },
-        Some(Function::Month) => match parse_datetime(&function_arg) {
+        Function::Month => match parse_datetime(&function_arg) {
             Ok(date) => Variant::from_int(date.0.month() as i64),
             _ => Variant::empty(VariantType::Int),
         },
-        Some(Function::Day) => match parse_datetime(&function_arg) {
+        Function::Day => match parse_datetime(&function_arg) {
             Ok(date) => Variant::from_int(date.0.day() as i64),
             _ => Variant::empty(VariantType::Int),
         },
-        Some(Function::DayOfWeek) => match parse_datetime(&function_arg) {
+        Function::DayOfWeek => match parse_datetime(&function_arg) {
             Ok(date) => Variant::from_int(date.0.weekday().number_from_sunday() as i64),
             _ => Variant::empty(VariantType::Int),
         },
         
         #[cfg(all(unix, feature = "users"))]
-        Some(Function::CurrentUid) => Variant::from_int(uzers::get_current_uid() as i64),
+        Function::CurrentUid => Variant::from_int(uzers::get_current_uid() as i64),
         #[cfg(all(unix, feature = "users"))]
-        Some(Function::CurrentUser) => {
+        Function::CurrentUser => {
             match uzers::get_current_username().and_then(|u| u.into_string().ok()) {
                 Some(s) => Variant::from_string(&s),
                 None => Variant::empty(VariantType::String),
             }
         }
         #[cfg(all(unix, feature = "users"))]
-        Some(Function::CurrentGid) => Variant::from_int(uzers::get_current_gid() as i64),
+        Function::CurrentGid => Variant::from_int(uzers::get_current_gid() as i64),
         #[cfg(all(unix, feature = "users"))]
-        Some(Function::CurrentGroup) => {
+        Function::CurrentGroup => {
             match uzers::get_current_groupname().and_then(|u| u.into_string().ok()) {
                 Some(s) => Variant::from_string(&s),
                 None => Variant::empty(VariantType::String),
             }
         }
         // ===== File functions =====
-        Some(Function::Contains) => {
+        Function::Contains => {
             if file_info.is_some() {
                 return Variant::empty(VariantType::Bool);
             }
@@ -798,7 +830,7 @@ pub fn get_value(
             Variant::empty(VariantType::Bool)
         }
         #[cfg(unix)]
-        Some(Function::HasXattr) => {
+        Function::HasXattr => {
             if let Some(entry) = entry {
                 if let Ok(file) = File::open(entry.path()) {
                     if let Ok(xattr) = file.get_xattr(&function_arg) {
@@ -810,7 +842,7 @@ pub fn get_value(
             Variant::empty(VariantType::Bool)
         }
         #[cfg(unix)]
-        Some(Function::Xattr) => {
+        Function::Xattr => {
             if let Some(entry) = entry {
                 if let Ok(file) = File::open(entry.path()) {
                     if let Ok(Some(xattr)) = file.get_xattr(&function_arg) {
@@ -824,7 +856,7 @@ pub fn get_value(
             Variant::empty(VariantType::String)
         }
         #[cfg(target_os = "linux")]
-        Some(Function::HasCapabilities) => {
+        Function::HasCapabilities => {
             if let Some(entry) = entry {
                 if let Ok(file) = File::open(entry.path()) {
                     if let Ok(caps_xattr) = file.get_xattr("security.capability") {
@@ -836,7 +868,7 @@ pub fn get_value(
             Variant::empty(VariantType::Bool)
         }
         #[cfg(target_os = "linux")]
-        Some(Function::HasCapability) => {
+        Function::HasCapability => {
             if let Some(entry) = entry {
                 if let Ok(file) = File::open(entry.path()) {
                     if let Ok(Some(caps_xattr)) = file.get_xattr("security.capability") {
@@ -849,7 +881,7 @@ pub fn get_value(
             Variant::empty(VariantType::Bool)
         }
         // ===== Miscellaneous functions =====
-        Some(Function::Coalesce) => {
+        Function::Coalesce => {
             if !&function_arg.is_empty() {
                 return Variant::from_string(&function_arg);
             }
@@ -862,7 +894,7 @@ pub fn get_value(
 
             Variant::empty(VariantType::String)
         }
-        Some(Function::Random) => {
+        Function::Random => {
             let mut rng = rand::rng();
 
             if function_arg.is_empty() {
@@ -890,7 +922,6 @@ pub fn get_value(
                 ),
             }
         }
-        // If no function is specified, return the original value
         _ => Variant::empty(VariantType::String),
     }
 }
@@ -898,7 +929,7 @@ pub fn get_value(
 /// Retrieves an aggregated value from a data buffer based on the specified function and key.
 ///
 /// Args:
-///   function: Optional specification of which aggregate function to apply.
+///   function: The specification which aggregate function to apply.
 ///   raw_output_buffer: A vector of hashmaps, where each hashmap contains string key-value pairs.
 ///   buffer_key: The key to look up in each hashmap of the buffer.
 ///   default_value: An optional default value to return if the function is not specified.
@@ -906,14 +937,13 @@ pub fn get_value(
 /// Returns:
 ///   A string representation of the aggregate value computed or the default value if no function is provided.
 pub fn get_aggregate_value(
-    function: &Option<Function>,
+    function: &Function,
     raw_output_buffer: &Vec<HashMap<String, String>>,
     buffer_key: String,
     default_value: &Option<String>,
 ) -> String {
-    //* Refer to the Function enum for a list of available functions and their descriptions
     match function {
-        Some(Function::Min) => {
+        Function::Min => {
             let min = raw_output_buffer
                 .iter()
                 .filter_map(|item| item.get(&buffer_key)) // Get the value from the buffer
@@ -923,7 +953,7 @@ pub fn get_aggregate_value(
 
             min.to_string()
         }
-        Some(Function::Max) => {
+        Function::Max => {
             let max = raw_output_buffer
                 .iter()
                 .filter_map(|item| item.get(&buffer_key)) // Get the values from the buffer
@@ -933,16 +963,16 @@ pub fn get_aggregate_value(
 
             max.to_string()
         }
-        Some(Function::Avg) => {
+        Function::Avg => {
             if raw_output_buffer.is_empty() {
                 return String::from("0");
             }
 
             get_mean(raw_output_buffer, &buffer_key).to_string()
         }
-        Some(Function::Sum) => get_buffer_sum(raw_output_buffer, &buffer_key).to_string(),
-        Some(Function::Count) => raw_output_buffer.len().to_string(),
-        Some(Function::StdDevPop) => {
+        Function::Sum => get_buffer_sum(raw_output_buffer, &buffer_key).to_string(),
+        Function::Count => raw_output_buffer.len().to_string(),
+        Function::StdDevPop => {
             if raw_output_buffer.is_empty() {
                 return String::new();
             }
@@ -953,7 +983,7 @@ pub fn get_aggregate_value(
 
             result.to_string()
         }
-        Some(Function::StdDevSamp) => {
+        Function::StdDevSamp => {
             if raw_output_buffer.is_empty() {
                 return String::new();
             }
@@ -965,7 +995,7 @@ pub fn get_aggregate_value(
 
             result.to_string()
         }
-        Some(Function::VarPop) => {
+        Function::VarPop => {
             if raw_output_buffer.is_empty() {
                 return String::new();
             }
@@ -975,7 +1005,7 @@ pub fn get_aggregate_value(
 
             variance.to_string()
         }
-        Some(Function::VarSamp) => {
+        Function::VarSamp => {
             if raw_output_buffer.is_empty() {
                 return String::new();
             }
@@ -987,8 +1017,6 @@ pub fn get_aggregate_value(
             variance.to_string()
         }
 
-        // If no function is specified, return the default value
-        // If no default value was specified, return an empty string
         _ => match &default_value {
             Some(val) => val.to_owned(),
             _ => String::new(),
@@ -1053,7 +1081,7 @@ mod tests {
         let entry = None;
         let file_info = None;
 
-        let result = get_value(&Some(function), function_arg, function_args, entry, &file_info);
+        let result = get_value(&function, function_arg, function_args, entry, &file_info);
         assert_eq!(result.to_string(), "hello");
     }
     
@@ -1065,7 +1093,7 @@ mod tests {
         let entry = None;
         let file_info = None;
 
-        let result = get_value(&Some(function), function_arg, function_args, entry, &file_info);
+        let result = get_value(&function, function_arg, function_args, entry, &file_info);
         assert_eq!(result.to_string(), "HELLO");
     }
     
@@ -1077,7 +1105,7 @@ mod tests {
         let entry = None;
         let file_info = None;
 
-        let result = get_value(&Some(function), function_arg, function_args, entry, &file_info);
+        let result = get_value(&function, function_arg, function_args, entry, &file_info);
         assert_eq!(result.to_string(), "Hello World");
     }
     
@@ -1089,7 +1117,7 @@ mod tests {
         let entry = None;
         let file_info = None;
 
-        let result = get_value(&Some(function), function_arg, function_args, entry, &file_info);
+        let result = get_value(&function, function_arg, function_args, entry, &file_info);
         assert_eq!(result.to_int(), 5);
     }
     
@@ -1101,7 +1129,7 @@ mod tests {
         let entry = None;
         let file_info = None;
 
-        let result = get_value(&Some(function), function_arg, function_args, entry, &file_info);
+        let result = get_value(&function, function_arg, function_args, entry, &file_info);
         assert_eq!(result.to_string(), "aGVsbG8=");
     }
     
@@ -1113,7 +1141,7 @@ mod tests {
         let entry = None;
         let file_info = None;
 
-        let result = get_value(&Some(function), function_arg, function_args, entry, &file_info);
+        let result = get_value(&function, function_arg, function_args, entry, &file_info);
         assert_eq!(result.to_string(), "hello");
     }
     
@@ -1125,7 +1153,7 @@ mod tests {
         let entry = None;
         let file_info = None;
 
-        let result = get_value(&Some(function), function_arg, function_args, entry, &file_info);
+        let result = get_value(&function, function_arg, function_args, entry, &file_info);
         assert_eq!(result.to_string(), "hello world");
     }
     
@@ -1137,7 +1165,7 @@ mod tests {
         let entry = None;
         let file_info = None;
 
-        let result = get_value(&Some(function), function_arg, function_args, entry, &file_info);
+        let result = get_value(&function, function_arg, function_args, entry, &file_info);
         assert_eq!(result.to_string(), "hello, world");
     }
     
@@ -1149,7 +1177,7 @@ mod tests {
         let entry = None;
         let file_info = None;
 
-        let result = get_value(&Some(function), function_arg, function_args, entry, &file_info);
+        let result = get_value(&function, function_arg, function_args, entry, &file_info);
         assert_eq!(result.to_int(), 7);
     }
     
@@ -1161,7 +1189,7 @@ mod tests {
         let entry = None;
         let file_info = None;
 
-        let result = get_value(&Some(function), function_arg, function_args, entry, &file_info);
+        let result = get_value(&function, function_arg, function_args, entry, &file_info);
         assert_eq!(result.to_string(), "world");
     }
     
@@ -1173,7 +1201,7 @@ mod tests {
         let entry = None;
         let file_info = None;
 
-        let result = get_value(&Some(function), function_arg, function_args, entry, &file_info);
+        let result = get_value(&function, function_arg, function_args, entry, &file_info);
         assert_eq!(result.to_string(), "hello Rust");
     }
     
@@ -1185,7 +1213,7 @@ mod tests {
         let entry = None;
         let file_info = None;
 
-        let result = get_value(&Some(function), function_arg, function_args, entry, &file_info);
+        let result = get_value(&function, function_arg, function_args, entry, &file_info);
         assert_eq!(result.to_string(), "hello");
     }
     
@@ -1197,7 +1225,7 @@ mod tests {
         let entry = None;
         let file_info = None;
 
-        let result = get_value(&Some(function), function_arg, function_args, entry, &file_info);
+        let result = get_value(&function, function_arg, function_args, entry, &file_info);
         assert_eq!(result.to_string(), "hello   ");
     }
     
@@ -1209,7 +1237,7 @@ mod tests {
         let entry = None;
         let file_info = None;
 
-        let result = get_value(&Some(function), function_arg, function_args, entry, &file_info);
+        let result = get_value(&function, function_arg, function_args, entry, &file_info);
         assert_eq!(result.to_string(), "   hello");
     }
     
@@ -1221,7 +1249,7 @@ mod tests {
         let entry = None;
         let file_info = None;
 
-        let result = get_value(&Some(function), function_arg, function_args, entry, &file_info);
+        let result = get_value(&function, function_arg, function_args, entry, &file_info);
         assert_eq!(result.to_string(), "1010");
     }
     
@@ -1233,7 +1261,7 @@ mod tests {
         let entry = None;
         let file_info = None;
 
-        let result = get_value(&Some(function), function_arg, function_args, entry, &file_info);
+        let result = get_value(&function, function_arg, function_args, entry, &file_info);
         assert_eq!(result.to_string(), "ff");
     }
     
@@ -1245,7 +1273,7 @@ mod tests {
         let entry = None;
         let file_info = None;
 
-        let result = get_value(&Some(function), function_arg, function_args, entry, &file_info);
+        let result = get_value(&function, function_arg, function_args, entry, &file_info);
         assert_eq!(result.to_string(), "10");
     }
     
@@ -1257,7 +1285,7 @@ mod tests {
         let entry = None;
         let file_info = None;
 
-        let result = get_value(&Some(function), function_arg, function_args, entry, &file_info);
+        let result = get_value(&function, function_arg, function_args, entry, &file_info);
         assert_eq!(result.to_int(), 10);
     }
     
@@ -1269,7 +1297,7 @@ mod tests {
         let entry = None;
         let file_info = None;
 
-        let result = get_value(&Some(function), function_arg, function_args, entry, &file_info);
+        let result = get_value(&function, function_arg, function_args, entry, &file_info);
         assert_eq!(result.to_int(), 8);
     }
     
@@ -1281,7 +1309,7 @@ mod tests {
         let entry = None;
         let file_info = None;
 
-        let result = get_value(&Some(function), function_arg, function_args, entry, &file_info);
+        let result = get_value(&function, function_arg, function_args, entry, &file_info);
         assert_eq!(result.to_int(), 4);
     }
     
@@ -1293,7 +1321,7 @@ mod tests {
         let entry = None;
         let file_info = None;
 
-        let result = get_value(&Some(function), function_arg, function_args, entry, &file_info);
+        let result = get_value(&function, function_arg, function_args, entry, &file_info);
         assert_eq!(result.to_int(), 2);
     }
     
@@ -1305,7 +1333,7 @@ mod tests {
         let entry = None;
         let file_info = None;
 
-        let result = get_value(&Some(function), function_arg, function_args, entry, &file_info);
+        let result = get_value(&function, function_arg, function_args, entry, &file_info);
         assert_eq!(result.to_int(), 1);
     }
     
@@ -1317,7 +1345,7 @@ mod tests {
         let entry = None;
         let file_info = None;
 
-        let result = get_value(&Some(function), function_arg, function_args, entry, &file_info);
+        let result = get_value(&function, function_arg, function_args, entry, &file_info);
         assert_eq!(result.to_float(), std::f64::consts::E);
     }
 
@@ -1329,7 +1357,7 @@ mod tests {
         let entry = None;
         let file_info = None;
 
-        let result = get_value(&Some(function), function_arg, function_args, entry, &file_info);
+        let result = get_value(&function, function_arg, function_args, entry, &file_info);
         assert_eq!(result.to_int(), 10);
     }
     
@@ -1341,10 +1369,22 @@ mod tests {
         let entry = None;
         let file_info = None;
 
-        let result = get_value(&Some(function), function_arg, function_args, entry, &file_info);
+        let result = get_value(&function, function_arg, function_args, entry, &file_info);
         assert_eq!(result.to_int(), 30);
     }
     
+    #[test]
+    fn function_pi() {
+        let function = Function::Pi;
+        let function_arg = String::new();
+        let function_args = vec![];
+        let entry = None;
+        let file_info = None;
+
+        let result = get_value(&function, function_arg, function_args, entry, &file_info);
+        assert_eq!(result.to_float(), std::f64::consts::PI);
+    }
+    
     #[test]
     fn function_contains_japanese() {
         let function = Function::ContainsJapanese;
@@ -1353,7 +1393,7 @@ mod tests {
         let entry = None;
         let file_info = None;
 
-        let result = get_value(&Some(function), function_arg, function_args, entry, &file_info);
+        let result = get_value(&function, function_arg, function_args, entry, &file_info);
         assert_eq!(result.to_bool(), true);
     }
     
@@ -1365,7 +1405,7 @@ mod tests {
         let entry = None;
         let file_info = None;
 
-        let result = get_value(&Some(function), function_arg, function_args, entry, &file_info);
+        let result = get_value(&function, function_arg, function_args, entry, &file_info);
         assert_eq!(result.to_bool(), true);
     }
     
@@ -1377,7 +1417,7 @@ mod tests {
         let entry = None;
         let file_info = None;
 
-        let result = get_value(&Some(function), function_arg, function_args, entry, &file_info);
+        let result = get_value(&function, function_arg, function_args, entry, &file_info);
         assert_eq!(result.to_bool(), true);
     }
     
@@ -1389,7 +1429,7 @@ mod tests {
         let entry = None;
         let file_info = None;
 
-        let result = get_value(&Some(function), function_arg, function_args, entry, &file_info);
+        let result = get_value(&function, function_arg, function_args, entry, &file_info);
         assert_eq!(result.to_bool(), true);
     }
     
@@ -1401,7 +1441,7 @@ mod tests {
         let entry = None;
         let file_info = None;
 
-        let result = get_value(&Some(function), function_arg, function_args, entry, &file_info);
+        let result = get_value(&function, function_arg, function_args, entry, &file_info);
         assert_eq!(result.to_bool(), true);
     }
     
@@ -1413,7 +1453,7 @@ mod tests {
         let entry = None;
         let file_info = None;
 
-        let result = get_value(&Some(function), function_arg, function_args, entry, &file_info);
+        let result = get_value(&function, function_arg, function_args, entry, &file_info);
         assert_eq!(result.to_string(), "1 KiB");
     }
     
@@ -1425,7 +1465,7 @@ mod tests {
         let entry = None;
         let file_info = None;
 
-        let result = get_value(&Some(function), function_arg, function_args, entry, &file_info);
+        let result = get_value(&function, function_arg, function_args, entry, &file_info);
         assert_eq!(result.to_string(), "1h");
     }
     
@@ -1437,7 +1477,7 @@ mod tests {
         let entry = None;
         let file_info = None;
 
-        let result = get_value(&Some(function), function_arg, function_args, entry, &file_info);
+        let result = get_value(&function, function_arg, function_args, entry, &file_info);
         assert_eq!(result.to_string(), format_date(&Local::now().date_naive()));
     }
     
@@ -1449,7 +1489,7 @@ mod tests {
         let entry = None;
         let file_info = None;
 
-        let result = get_value(&Some(function), function_arg, function_args, entry, &file_info);
+        let result = get_value(&function, function_arg, function_args, entry, &file_info);
         let s = result.to_string();
         // Expect format YYYY-MM-DD HH:MM:SS → length 19 and separators at fixed positions
         assert_eq!(s.len(), 19, "Unexpected CURRENT_TIMESTAMP length: {}", s);
@@ -1469,7 +1509,7 @@ mod tests {
         let entry = None;
         let file_info = None;
 
-        let result = get_value(&Some(function), function_arg, function_args, entry, &file_info);
+        let result = get_value(&function, function_arg, function_args, entry, &file_info);
         assert_eq!(result.to_int(), 1);
     }
     
@@ -1481,7 +1521,7 @@ mod tests {
         let entry = None;
         let file_info = None;
 
-        let result = get_value(&Some(function), function_arg, function_args, entry, &file_info);
+        let result = get_value(&function, function_arg, function_args, entry, &file_info);
         assert_eq!(result.to_int(), 10);
     }
     
@@ -1493,7 +1533,7 @@ mod tests {
         let entry = None;
         let file_info = None;
 
-        let result = get_value(&Some(function), function_arg, function_args, entry, &file_info);
+        let result = get_value(&function, function_arg, function_args, entry, &file_info);
         assert_eq!(result.to_int(), 2023);
     }
     
@@ -1505,7 +1545,7 @@ mod tests {
         let entry = None;
         let file_info = None;
 
-        let result = get_value(&Some(function), function_arg, function_args, entry, &file_info);
+        let result = get_value(&function, function_arg, function_args, entry, &file_info);
         assert_eq!(result.to_int(), 1);
     }
     
@@ -1518,7 +1558,7 @@ mod tests {
         let entry = None;
         let file_info = None;
 
-        let result = get_value(&Some(function), function_arg, function_args, entry, &file_info);
+        let result = get_value(&function, function_arg, function_args, entry, &file_info);
         assert_eq!(result.to_int(), uzers::get_current_uid() as i64);
     }
     
@@ -1531,7 +1571,7 @@ mod tests {
         let entry = None;
         let file_info = None;
 
-        let result = get_value(&Some(function), function_arg, function_args, entry, &file_info);
+        let result = get_value(&function, function_arg, function_args, entry, &file_info);
         assert_eq!(result.to_string(), uzers::get_current_username().unwrap().to_string_lossy().to_string());
     }
     
@@ -1544,7 +1584,7 @@ mod tests {
         let entry = None;
         let file_info = None;
 
-        let result = get_value(&Some(function), function_arg, function_args, entry, &file_info);
+        let result = get_value(&function, function_arg, function_args, entry, &file_info);
         assert_eq!(result.to_int(), uzers::get_current_gid() as i64);
     }
     
@@ -1557,7 +1597,7 @@ mod tests {
         let entry = None;
         let file_info = None;
 
-        let result = get_value(&Some(function), function_arg, function_args, entry, &file_info);
+        let result = get_value(&function, function_arg, function_args, entry, &file_info);
         assert_eq!(result.to_string(), uzers::get_current_groupname().unwrap().to_string_lossy().to_string());
     }
     
@@ -1569,7 +1609,7 @@ mod tests {
         let entry = None;
         let file_info = None;
 
-        let result = get_value(&Some(function), function_arg, function_args, entry, &file_info);
+        let result = get_value(&function, function_arg, function_args, entry, &file_info);
         assert_eq!(result.to_string(), "hello");
     }
 }
\ No newline at end of file
