@@ -9,7 +9,7 @@ pub struct CsvFormatter {
 }
 
 impl ResultsFormatter for CsvFormatter {
-    fn header(&mut self) -> Option<String> {
+    fn header(&mut self, _: String, _: usize) -> Option<String> {
         None
     }
 
